//
//  LSPasswordController.h
//  LightSpeed Cocoa
//
//  Created by Yves Meynard on 2011/03/23.
//  Copyright 2011 Xsilva Systems. All rights reserved.
//

#import <Cocoa/Cocoa.h>

#import "LSBDecoratingIcons.h"
#import "LSDecoratedTextFieldCellProtocol.h"

typedef enum {
	LSUserChangePasswordMode, // A user changing their password
	LSAdminChangePasswordMode, // An administrator changing another user's password
	LSExpiredChangePasswordMode,
}  LSChangePasswordMode;

/*! The three images we can display in a password text field, plus "none". */
typedef enum {
	LSNoImage,
	LSWrongPasswordImage,
	LSInsecurePasswordImage,
	LSSecurePasswordImage,
} LSPasswordImage;

@class LSDecoratedSecureTextField;
@class LSChangePasswordInfo;
@class XSFBindingHelper;

/*! This class implements the presentation logic required for password fields, displaying the proper icons as the user types.
 *  It does not implement saving the information. That is a job for the window or view controller that owns this LSPasswordController.
 *  Note that bindings must still be defined within the nib file for the owning controller.
 */
@interface LSPasswordController : NSObject {
	LSDecoratedSecureTextField* oldPasswordField;
	LSDecoratedSecureTextField* newPasswordField;
	LSDecoratedSecureTextField* verifyPasswordField;

	NSTextField* incorrectPasswordLabel;
	NSTextField* passwordMatchesPreviousLabel;
	
	LSChangePasswordInfo* passwordInfo;
	XSFBindingHelper* binder;
	LSChangePasswordMode mode;
}

@property(nonatomic, retain) LSDecoratedSecureTextField * oldPasswordField;
@property(nonatomic, retain) LSDecoratedSecureTextField * newPasswordField;
@property(nonatomic, retain) LSDecoratedSecureTextField * verifyPasswordField;

@property(nonatomic, retain) NSTextField * incorrectPasswordLabel;
@property(nonatomic, retain) NSTextField * passwordMatchesPreviousLabel;

@property(nonatomic, retain, readonly) LSChangePasswordInfo* passwordInfo;

/*! Init with mode; we create our own LSChangePasswordInfo object. */
- (id) initWithMode: (LSChangePasswordMode) inMode;

/*! Init with a given mode and a pre-existing password info object. Designated initializer. */
- (id) initWithMode: (LSChangePasswordMode) inMode passwordInfo:(LSChangePasswordInfo*) info;

/*! Return NO if all the password fields are blank, indicating the user does not wish to update a password. */
- (BOOL) areAnyFieldsModified;

/*! Call this once the password fields are defined, to avoid a UI glitch. */
- (void) primePasswordFields;

/*! Indicate that the old password failed validation. */
- (void) updateFieldsForOldPasswordFailed;

/*! Indicate that the new password failed validation. */
- (void) updateFieldsForNewPasswordFailed;

/*! Obtain the name of the icon corresponding to a status. */
+ (LSDecoratingIcon) iconForPasswordImage: (LSPasswordImage) img;

@end
