//
//  NSImage-XSAExtensions.h
//  LightSpeed Cocoa
//
//  Created by Joseph Ranieri on 3/4/10.
//  Copyright 2010 Xsilva Systems. All rights reserved.
//

#import <Cocoa/Cocoa.h>

@interface NSImage (XSAExtensions)

/*!
 @method drawInView:inRect:
 @abstract Draws this image in the given view.
 @discussion The image will be drawn inside rect, resizing it if needed to fill
             the entire rectangle. Note that this method requires that the view
			 passed be the current drawing context.
 @param view The view to draw in.
 @param rect The rectangle to fill. This is in the view's co-ordinates.
*/
- (void)drawInView:(NSView *)view inRect:(NSRect)rect;

/*!
 @method drawInView:inRect:operation:
 @abstract Draws this image in the given view.
 @discussion The image will be drawn inside rect, resizing it if needed to fill
 the entire rectangle. Note that this method requires that the view
 passed be the current drawing context.
 @param view The view to draw in.
 @param rect The rectangle to fill. This is in the view's co-ordinates.
 @param op The compositing operation.
 */
- (void)drawInView:(NSView *)view inRect:(NSRect)rect operation:(NSCompositingOperation)op;

/*!
 @method drawInView:atPoint:
 @abstract Draws this image in the given view.
 @discussion The image will be drawn at the given point. No resizing will be
             performed and the image will be drawn at its normal size. Note that
			 this method requires that the view passed be the current drawing context.
 @param view The view to draw in.
 @param point The point to draw the image. This is in the view's co-ordinates.
*/
- (void)drawInView:(NSView *)view atPoint:(NSPoint)point;

/*!
 @method tileInView:inRect:
 @abstract Tiles this image in the specified rect in the specified view.
 @discussion This tiles the image using an NSColor pattern. This is pretty efficient as it lets Quartz do the tiling and clipping.
			 The NSCompositeCopy operation is used for performance reason. 
 @param view The view to draw in.
 @param tilingRect the rectangle to fill with the image tiles. This is in the view's co-ordinates.
 */
-(void)tileInView:(NSView *)view inRect:(NSRect)tilingRect;

/*!
 @method tileInView:inRect:
 @abstract Tiles this image in the specified rect in the specified view.
 @discussion This tiles the image using an NSColor pattern. This is pretty efficient as it lets Quartz do the tiling and clipping.
 @param view The view to draw in.
 @param tilingRect the rectangle to fill with the image tiles. This is in the view's co-ordinates.
 @param anchorPoint, sets the origin the of pattern in relative the to the tiling rect. {0,0} specifies the origin, {0, 1.0} the top
		left corner, {0.5, 0.5} for the middle.
 @param op the compositing operation to use.
 */
-(void)tileInView:(NSView *)view inRect:(NSRect)tilingRect anchorPoint:(NSPoint)anchorPoint usingOperation:(NSCompositingOperation)op;

@end

