/*
 *  NSWindowProperties.h
 *  BlackIce
 *
 *  Created by Joseph Ranieri on 8/29/09.
 *  Copyright 2009 Xsilva Systems. All rights reserved.
 *
 */

#import <AppKit/AppKit.h>

@interface NSWindow (properties)
@property(copy) NSString *title;
@property(retain) NSURL *representedURL;
@property(copy) NSString *representedFilename;
@property BOOL isExcludedFromWindowsMenu;
@property(retain) NSView *contentView;

#ifdef MAC_OS_X_VERSION_10_6
@property(assign) id<NSWindowDelegate> delegate;
#else
@property(assign) id delegate;
#endif

@property(readonly) NSInteger windowNumber;

#if MAC_OS_X_VERSION_MIN_REQUIRED < MAC_OS_X_VERSION_10_6
@property(readonly) NSUInteger styleMask;
#else
@property NSUInteger styleMask;
#endif

@property(readonly) NSRect frame;
@property BOOL showsResizeIndicator;
@property NSSize resizeIncrements;
@property NSSize aspectRatio;
@property NSSize contentResizeIncrements;
@property NSSize contentAspectRatio;
@property(readonly) BOOL isFlushWindowDisabled;
@property BOOL viewsNeedDisplay;
@property(getter=isAutodisplay, setter=setAutodisplay:) BOOL isAutodisplay;
@property BOOL preservesContentDuringLiveResize;
@property(readonly) NSResponder *firstResponder;
@property(readonly) NSInteger resizeFlags;
@property(getter=isReleasedWhenClosed, setter=setReleasedWhenClosed:) BOOL isReleasedWhenClosed;
@property(readonly) BOOL isZoomed;
@property(readonly) BOOL isMiniaturized;
@property(retain) NSColor *backgroundColor;
@property(getter=isMovableByWindowBackground, setter=setMovableByWindowBackground:) BOOL isMovableByWindowBackground;
@property BOOL hidesOnDeactivate;
@property BOOL canHide;
@property(retain) NSImage *miniwindowImage;
@property(copy) NSString *miniWindowTitle;
@property(readonly) NSDockTile *dockTile;
@property(getter=isDocumentEdited, setter=setDocumentEdited:) BOOL isDocumentEdited;
@property(readonly) BOOL isVisible;
@property(readonly) BOOL isKeyWindow;
@property(readonly) BOOL isMainWindow;
@property(readonly) BOOL canBecomeKeyWindow;
@property(readonly) BOOL canBecomeMainWindow;
@property(readonly) BOOL worksWhenModal;
@property(getter=isOneShot, setter=setOneShot:) BOOL isOneShot;
@property(readonly) BOOL areCursorRectsEnabled;
@property BOOL allowsToolTipsWhenApplicationIsInactive;
@property NSBackingStoreType backingType;
@property NSInteger level;
@property NSWindowDepth depthLimit;
@property(getter=hasDynamicDepthLimit, setter=setDynamicDepthLimit:) BOOL hasDynamicDepthLimit;
@property(readonly) NSScreen *screen;
@property(readonly) NSScreen *deepestScreen;
@property(readonly) BOOL canStoreColor;
@property BOOL hasShadow;
@property CGFloat alphaValue;
@property(getter=isOpaque, setter=setOpaque:) BOOL isOpaque;
@property NSWindowSharingType sharingType;
@property NSWindowBackingLocation preferredBackingLocation;
@property(readonly) NSWindowBackingLocation backingLocation;
@property BOOL displaysWhenScreenProfileChanges;
@property BOOL canBecomeVisibleWithoutLogin;
@property NSWindowCollectionBehavior collectionBehavior;
@property(copy) NSString *frameAutosaveName;
@property NSSize minSize;
@property NSSize maxSize;
@property NSSize contentMinSize;
@property NSSize contentMaxSize;
@property(readonly) NSEvent *currentEvent;
@property BOOL acceptsMouseMovedEvents;
@property BOOL ignoresMouseEvents;
@property(readonly) NSDictionary *deviceDescription;
@property(readonly) NSPoint mouseLocationOutsideOfEventStream;
@property(retain) NSWindowController *windowController;
@property(readonly) BOOL isSheet;
@property(readonly) NSWindow *attachedSheet;
@property(readonly) NSArray *childWindows;
@property(retain) NSWindow *parentWindow;
@property(readonly) NSGraphicsContext *graphicsContext;
@property(readonly) CGFloat userSpaceScaleFactor;

#ifdef MAC_OS_X_VERSION_10_6
@property(readonly) BOOL inLiveResize AVAILABLE_MAC_OS_X_VERSION_10_6_AND_LATER;
@property(getter=isMovable, setter=setMovable:) BOOL isMovable AVAILABLE_MAC_OS_X_VERSION_10_6_AND_LATER;
@property BOOL preventsApplicationTerminationWhenModal AVAILABLE_MAC_OS_X_VERSION_10_6_AND_LATER;
@property BOOL allowsConcurrentViewDrawing AVAILABLE_MAC_OS_X_VERSION_10_6_AND_LATER;
@property(readonly) BOOL isOnActiveSpace AVAILABLE_MAC_OS_X_VERSION_10_6_AND_LATER;
@property(retain) NSColorSpace *colorSpace AVAILABLE_MAC_OS_X_VERSION_10_6_AND_LATER;
#endif


// NSKeyboardUI
@property(retain) NSView *initialFirstResponder;
@property(readonly) NSSelectionDirection keyViewSelectionDirection;
@property(readonly) NSButtonCell *defaultButtonCell;
@property BOOL autorecalculatesKeyViewLoop;

// NSToolbarSupport
@property(retain) NSToolbar *toolbar;
@property BOOL showsToolbarButton;

// NSCarbonExtensions
@property(readonly) void *windowRef;
@end
